@@ -1,31 +1,37 @@
-/* libgc is a wrapper library to fill the gaps between Gjs and
-   libunistring, pango, GTK+.  */
+/* libgc is a wrapper library to fill the gaps between Gjs and GLib.  */
 
 #ifndef __GC_H__
 #define __GC_H__
 
 #include <gio/gio.h>
-#include <gtk/gtk.h>
-#include <pango/pango.h>
 #include "gc-enumtypes.h"
 
 G_BEGIN_DECLS
 
-/* libunistring support.  In libunistring, the Unicode general
-   categories are defined as global constant, which is not accessible
-   through GI.  */
-
+/**
+ * GcCategory:
+ */
 typedef enum
 {
   GC_CATEGORY_NONE,
-  GC_CATEGORY_PUNCTUATION,
-  GC_CATEGORY_ARROW,
-  GC_CATEGORY_BULLET,
-  GC_CATEGORY_PICTURE,
-  GC_CATEGORY_CURRENCY,
-  GC_CATEGORY_MATH,
-  GC_CATEGORY_LATIN,
-  GC_CATEGORY_EMOTICON
+  GC_CATEGORY_LETTER,
+  GC_CATEGORY_LETTER_PUNCTUATION,
+  GC_CATEGORY_LETTER_ARROW,
+  GC_CATEGORY_LETTER_BULLET,
+  GC_CATEGORY_LETTER_PICTURE,
+  GC_CATEGORY_LETTER_CURRENCY,
+  GC_CATEGORY_LETTER_MATH,
+  GC_CATEGORY_LETTER_LATIN,
+  GC_CATEGORY_EMOJI,
+  GC_CATEGORY_EMOJI_SMILEYS,
+  GC_CATEGORY_EMOJI_PEOPLE,
+  GC_CATEGORY_EMOJI_ANIMALS,
+  GC_CATEGORY_EMOJI_FOOD,
+  GC_CATEGORY_EMOJI_ACTIVITIES,
+  GC_CATEGORY_EMOJI_TRAVEL,
+  GC_CATEGORY_EMOJI_OBJECTS,
+  GC_CATEGORY_EMOJI_SYMBOLS,
+  GC_CATEGORY_EMOJI_FLAGS,
 } GcCategory;
 
 /* Provides asynchronous access to Unicode characters with the given
@@ -33,7 +39,7 @@ typedef enum
    search criteria written in JS, because the JS code needs to be run
    in the main thread.  */
 
-typedef GArray GcSearchResult;
+typedef GPtrArray GcSearchResult;
 typedef gboolean (*GcSearchFunc) (gunichar uc, gpointer user_data);
 
 #define GC_SEARCH_ERROR (gc_search_error_quark ())
@@ -60,7 +66,7 @@ G_DECLARE_FINAL_TYPE (GcSearchContext, gc_search_context,
 
 GType                 gc_search_result_get_type
                                             (void);
-gunichar              gc_search_result_get  (GcSearchResult       *result,
+const char           *gc_search_result_get  (GcSearchResult       *result,
                                              gint                  index);
 
 GType                 gc_search_criteria_get_type
@@ -73,10 +79,11 @@ GcSearchCriteria     *gc_search_criteria_new_keywords
                                             (const gchar * const * keywords);
 
 GcSearchCriteria     *gc_search_criteria_new_scripts
-                                            (const gchar * const * scripts);
+                                            (const GUnicodeScript *scripts,
+                                             size_t                n_scripts);
 
 GcSearchCriteria     *gc_search_criteria_new_related
-                                            (gunichar              uc);
+                                            (const gchar          *character);
 
 GcSearchContext      *gc_search_context_new (GcSearchCriteria     *criteria,
                                              GcSearchFlag          flags);
@@ -93,30 +100,20 @@ GcSearchResult       *gc_search_context_search_finish
 gboolean              gc_search_context_is_finished
                                             (GcSearchContext      *context);
 
-gchar                *gc_character_name     (gunichar              uc);
+gboolean              gc_character_is_composite
+                                            (const gunichar       *chars,
+                                             int                   n_chars);
+gchar                *gc_character_name     (const gunichar       *chars,
+                                             int                   n_chars);
 gboolean              gc_character_is_invisible
-                                            (gunichar              uc);
-gint                  gc_character_width    (gunichar              uc);
-
-
-/* GTK+ support.  gtk_clipboard_get() takes an GdkAtom as the first
-   argument, but GdkAtom is not accessible through GI.  */
-
-GtkClipboard         *gc_gtk_clipboard_get  (void);
-
-/* Pango support.  PangoAttrFallback is not accessible from GI.  */
-void                  gc_pango_layout_disable_fallback
-                                            (PangoLayout          *layout);
-
-gboolean              gc_pango_context_font_has_glyph
-                                            (PangoContext         *context,
-                                             PangoFont            *font,
-                                             gunichar              uc);
+                                            (const gunichar       *chars,
+                                             int                   n_chars);
 
 gchar                *gc_get_current_language
                                             (void);
-const gchar * const * gc_get_scripts_for_language
-                                            (const gchar          *language);
+GUnicodeScript       *gc_get_scripts_for_language
+                                            (const gchar          *language,
+                                             size_t               *n_scripts);
 
 G_END_DECLS
 
