@@ -13,11 +13,13 @@ wget -c "https://www.unicode.org/Public/emoji/$EMOJI_VERSION/emoji-test.txt"
 wget -c "https://www.unicode.org/Public/security/$UCD_VERSION/confusables.txt"
 
 unzip -jo core.zip common/supplemental/supplementalData.xml
+unzip -jo core.zip common/supplemental/supplementalMetadata.xml
 
 ./gen-blocks.py Blocks.txt > blocks.h
 ./gen-confusables.py confusables.txt > confusables.h
 ./gen-emoji.py emoji-test.txt > emoji.h
 ./gen-hangul.py Jamo.txt > hangul.h
+./gen-languages.py supplementalMetadata.xml > languages.h
 ./gen-names.py UnicodeData.txt emoji-test.txt > names.h
 ./gen-scripts.py supplementalData.xml PropertyValueAliases.txt > scripts.h
 
@@ -27,5 +29,6 @@ rm PropertyValueAliases.txt
 rm UnicodeData.txt
 rm core.zip
 rm supplementalData.xml
+rm supplementalMetadata.xml
 rm emoji-test.txt
-rm confusables.txt
+rm confusables.txt
\ No newline at end of file
