@@ -1,4 +1,4 @@
-#define NLANGUAGES 1154
+#define NLANGUAGES 1176
 struct LanguageScripts
 {
   const gchar *language;
@@ -34,6 +34,8 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ann", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "anp", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "aoz", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "apc", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
+    { "apd", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ar_AE", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ar_BH", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "ar_DJ", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
@@ -115,6 +117,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "bin", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "bjj", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "bjn", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "bjt", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "bkm", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "bku", { N_("Buhid"), NULL }, { 0x42756864, 0 } },
     { "bla", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -133,6 +136,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "brh_PK", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "brx", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "bs_BA", { N_("Cyrillic"), N_("Latin"), NULL }, { 0x4379726c, 0x4c61746e, 0 } },
+    { "bsc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "bss", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "bto", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "btv", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
@@ -152,6 +156,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "cay", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cch", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ccp", { N_("Bengali"), N_("Chakma"), NULL }, { 0x42656e67, 0x43616b6d, 0 } },
+    { "ccr", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ce", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "ceb", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cgg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -172,7 +177,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ckt", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "clc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "co", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "cop", { N_("Arabic"), N_("Coptic"), N_("Greek"), NULL }, { 0x41726162, 0x436f7074, 0x4772656b, 0 } },
+    { "cop_EG", { N_("Arabic"), N_("Coptic"), N_("Greek"), NULL }, { 0x41726162, 0x436f7074, 0x4772656b, 0 } },
     { "cps", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cr", { N_("Canadian_Aboriginal"), N_("Latin"), NULL }, { 0x43616e73, 0x4c61746e, 0 } },
     { "crg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -183,7 +188,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "crm", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
     { "crs", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cs_CZ", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "csb_PL", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "csb", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "csw", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
     { "ctd", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "cu", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
@@ -296,6 +301,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "en_GI", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_GM", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_GR", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
+    { "en_GS", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_GU", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_GY", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_HK", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -327,6 +333,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "en_MA", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
     { "en_MG", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MH", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "en_MO", { N_("Deseret"), N_("Shavian"), NULL }, { 0x44737274, 0x53686177, 0 } },
     { "en_MP", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MS", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "en_MT", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -433,6 +440,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "fj_FJ", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fo_FO", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fon", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "fr_AT", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
     { "fr_BE", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_BF", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_BI", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -458,6 +466,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "fr_HT", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_IT", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
     { "fr_KM", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "fr_LB", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
     { "fr_LU", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_MA", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_MC", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -477,7 +486,8 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "fr_RW", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_SC", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_SN", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "fr_SY", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "fr_ST", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
+    { "fr_SY", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
     { "fr_TD", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "fr_TF", { N_("Duployan"), NULL }, { 0x4475706c, 0 } },
     { "fr_TG", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -538,7 +548,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "gwi", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ha", { N_("Arabic"), N_("Latin"), NULL }, { 0x41726162, 0x4c61746e, 0 } },
     { "hai", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "hak", { N_("Han"), NULL }, { 0x48616e69, 0 } },
+    { "hak_TW", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "haw", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "haz", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "he_IL", { N_("Hebrew"), NULL }, { 0x48656272, 0 } },
@@ -585,6 +595,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "ilo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "inh", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "inh_RU", { N_("Arabic"), N_("Latin"), NULL }, { 0x41726162, 0x4c61746e, 0 } },
+    { "io", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "is_IS", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "it_CH", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "it_IT", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -594,6 +605,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "izh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ja_JP", { N_("Hiragana"), N_("Katakana"), NULL }, { 0x48726b74, 0 } },
     { "jam", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "jbo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "jgo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "jmc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "jml", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
@@ -609,7 +621,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "kaj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kam", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kao", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "kaw", { N_("Balinese"), N_("Javanese"), N_("Kawi"), NULL }, { 0x42616c69, 0x4a617661, 0x4b617769, 0 } },
+    { "kaw", { N_("Javanese"), N_("Kawi"), NULL }, { 0x4a617661, 0x4b617769, 0 } },
     { "kbd", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "kca", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "kcg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -617,6 +629,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "kde", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kdt", { N_("Thai"), NULL }, { 0x54686169, 0 } },
     { "kea", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "ken", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kfo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kfr", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "kfy", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
@@ -642,6 +655,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "km_KH", { N_("Khmer"), NULL }, { 0x4b686d72, 0 } },
     { "kmb", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "kn", { N_("Kannada"), NULL }, { 0x4b6e6461, 0 } },
+    { "knf", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "knn", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "ko_KP", { N_("Hangul"), NULL }, { 0x48616e67, 0 } },
     { "ko_KR", { N_("Hangul"), NULL }, { 0x48616e67, 0 } },
@@ -674,7 +688,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "kxv", { N_("Devanagari"), N_("Oriya"), N_("Telugu"), NULL }, { 0x44657661, 0x4f727961, 0x54656c75, 0 } },
     { "ky_KG", { N_("Arabic"), N_("Cyrillic"), N_("Latin"), NULL }, { 0x41726162, 0x4379726c, 0x4c61746e, 0 } },
     { "kyu", { N_("Kayah_Li"), NULL }, { 0x4b616c69, 0 } },
-    { "la_VA", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "la", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lab", { N_("Linear_A"), NULL }, { 0x4c696e61, 0 } },
     { "lad", { N_("Hebrew"), NULL }, { 0x48656272, 0 } },
     { "lag", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -685,6 +699,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "lbe", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "lbw", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lcp", { N_("Thai"), NULL }, { 0x54686169, 0 } },
+    { "len", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lep", { N_("Lepcha"), NULL }, { 0x4c657063, 0 } },
     { "lez", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "lez_RU", { N_("Caucasian_Albanian"), NULL }, { 0x41676862, 0 } },
@@ -721,7 +736,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "lv_LV", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "lwl", { N_("Thai"), NULL }, { 0x54686169, 0 } },
     { "lzh", { N_("Han"), NULL }, { 0x48616e69, 0 } },
-    { "lzz", { N_("Georgian"), N_("Latin"), NULL }, { 0x47656f72, 0x4c61746e, 0 } },
+    { "lzz", { N_("Georgian"), NULL }, { 0x47656f72, 0 } },
     { "mad", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "maf", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mag", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
@@ -742,6 +757,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "mer", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mfa", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "mfe", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "mfv", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mg_MG", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mgh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "mgo", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -789,7 +805,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "myz", { N_("Mandaic"), NULL }, { 0x4d616e64, 0 } },
     { "mzn", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "na_NR", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "nan", { N_("Han"), NULL }, { 0x48616e69, 0 } },
+    { "nan_TW", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "nap", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "naq", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "nb_NO", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -839,6 +855,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "oc", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "oj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "ojs", { N_("Canadian_Aboriginal"), NULL }, { 0x43616e73, 0 } },
+    { "ojw", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "oka", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "om", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "om_ET", { N_("Ethiopic"), NULL }, { 0x45746869, 0 } },
@@ -866,8 +883,9 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "pko", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "pl_PL", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "pms", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "pnt", { N_("Cyrillic"), N_("Greek"), N_("Latin"), NULL }, { 0x4379726c, 0x4772656b, 0x4c61746e, 0 } },
+    { "pnt", { N_("Cyrillic"), N_("Latin"), NULL }, { 0x4379726c, 0x4c61746e, 0 } },
     { "pon", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "ppl", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "pqm", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "prd", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
     { "prg", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -956,7 +974,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "sel", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "ses", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "sg_CF", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "sga", { N_("Latin"), N_("Ogham"), NULL }, { 0x4c61746e, 0x4f67616d, 0 } },
+    { "sga", { N_("Ogham"), NULL }, { 0x4f67616d, 0 } },
     { "sgs", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "shi", { N_("Arabic"), N_("Latin"), N_("Tifinagh"), NULL }, { 0x41726162, 0x4c61746e, 0x54666e67, 0 } },
     { "shn", { N_("Myanmar"), NULL }, { 0x4d796d72, 0 } },
@@ -975,6 +993,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "smp", { N_("Samaritan"), NULL }, { 0x53616d72, 0 } },
     { "sms", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "sn_ZW", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "snf", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "snk", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "so_DJ", { N_("Arabic"), N_("Osmanya"), NULL }, { 0x41726162, 0x4f736d61, 0 } },
     { "so_ET", { N_("Arabic"), N_("Osmanya"), NULL }, { 0x41726162, 0x4f736d61, 0 } },
@@ -1041,12 +1060,14 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "tiv", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tk_TM", { N_("Arabic"), N_("Cyrillic"), N_("Latin"), NULL }, { 0x41726162, 0x4379726c, 0x4c61746e, 0 } },
     { "tkl_TK", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "tkr", { N_("Cyrillic"), N_("Latin"), NULL }, { 0x4379726c, 0x4c61746e, 0 } },
+    { "tkr", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "tkt", { N_("Devanagari"), NULL }, { 0x44657661, 0 } },
     { "tli", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "tly", { N_("Arabic"), N_("Cyrillic"), N_("Latin"), NULL }, { 0x41726162, 0x4379726c, 0x4c61746e, 0 } },
+    { "tly", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "tly_AZ", { N_("Arabic"), N_("Cyrillic"), NULL }, { 0x41726162, 0x4379726c, 0 } },
     { "tmh", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tn_BW", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
+    { "tnr", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "to_TO", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tog", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tok", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -1065,7 +1086,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "tt", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "ttj", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tts", { N_("Thai"), NULL }, { 0x54686169, 0 } },
-    { "ttt", { N_("Arabic"), NULL }, { 0x41726162, 0 } },
+    { "ttt", { N_("Arabic"), N_("Cyrillic"), NULL }, { 0x41726162, 0x4379726c, 0 } },
     { "tum", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "tvl_TV", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "twq", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -1138,7 +1159,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "yrk", { N_("Cyrillic"), NULL }, { 0x4379726c, 0 } },
     { "yrl", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "yua", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
-    { "yue", { N_("Han"), NULL }, { 0x48616e69, 0 } },
+    { "yue_MO", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "za", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "za_CN", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "zag", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
@@ -1147,6 +1168,7 @@ struct LanguageScripts language_scripts[NLANGUAGES] =
     { "zea", { N_("Latin"), NULL }, { 0x4c61746e, 0 } },
     { "zen", { N_("Tifinagh"), NULL }, { 0x54666e67, 0 } },
     { "zgh", { N_("Tifinagh"), NULL }, { 0x54666e67, 0 } },
+    { "zh_CA", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
     { "zh_CN", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "zh_HK", { N_("Han"), NULL }, { 0x48616e69, 0 } },
     { "zh_ID", { N_("Bopomofo"), N_("Latin"), N_("Phags_Pa"), NULL }, { 0x426f706f, 0x4c61746e, 0x50686167, 0 } },
