@@ -227,7 +227,6 @@ var CharactersView = GObject.registerClass({
         gestureClick.connect('pressed', this.onButtonPress.bind(this));
         gestureClick.connect('released', this.onButtonRelease.bind(this));
         this.add_controller(gestureClick);
-        this.add_css_class('view');
     }
 
     get fontDescription() {
@@ -464,23 +463,18 @@ var CharactersView = GObject.registerClass({
     // / and the input-sources settings.
     async populateScripts() {
         this.loading = true;
-        let settings =
-            Util.getSettings('org.gnome.desktop.input-sources',
-                '/org/gnome/desktop/input-sources/');
-        if (settings) {
-            let sources = settings.get_value('sources').deep_unpack();
-            let hasIBus = sources.some((current, _index, _array) => {
-                return current[0] === 'ibus';
-            });
-            if (hasIBus)
-                await this._ensureIBusLanguageList(sources);
-            else
-                this._finishBuildScriptList(sources);
-        }
+        let sources = await Util.getInputSources();
+        let hasIBus = sources.some((current, _index, _array) => {
+            return current[0] === 'ibus';
+        });
+        if (hasIBus)
+            await this._ensureIBusLanguageList(sources);
+        else
+            this._finishBuildScriptList(sources);
     }
 
     async _ensureIBusLanguageList(sources) {
-        if (this._ibusLanguageList !== null)
+        if (this._ibusLanguageList !== undefined)
             return;
 
         this._ibusLanguageList = {};
